Documentation
¶
Index ¶
- func EnsureCertInStatus(pem string, msg proto.Message) error
- func ParseCertFromPEMFile(pemData string) (*x509.Certificate, error)
- type AuditService
- type BackendService
- func (l *BackendService) Create(ctx context.Context, be *backendv1.Backend) (*backendv1.Backend, error)
- func (l *BackendService) Delete(ctx context.Context, id keys.ID) error
- func (l *BackendService) Get(ctx context.Context, id keys.ID) (*backendv1.Backend, error)
- func (l *BackendService) List(ctx context.Context, limit int32) ([]*backendv1.Backend, error)
- func (l *BackendService) Patch(ctx context.Context, id keys.ID, patch *backendv1.Backend) error
- func (l *BackendService) Update(ctx context.Context, id keys.ID, be *backendv1.Backend) error
- func (l *BackendService) UpdateStatus(ctx context.Context, id keys.ID, st *backendv1.BackendStatus, mask ...string) error
- type CertificateAuthorityService
- func (l *CertificateAuthorityService) Create(ctx context.Context, ca *cav1.CertificateAuthority) (*cav1.CertificateAuthority, error)
- func (l *CertificateAuthorityService) Delete(ctx context.Context, id keys.ID) error
- func (l *CertificateAuthorityService) Get(ctx context.Context, id keys.ID) (*cav1.CertificateAuthority, error)
- func (l *CertificateAuthorityService) List(ctx context.Context, limit int32) ([]*cav1.CertificateAuthority, error)
- func (l *CertificateAuthorityService) Patch(ctx context.Context, id keys.ID, patch *cav1.CertificateAuthority) error
- func (l *CertificateAuthorityService) Update(ctx context.Context, id keys.ID, ca *cav1.CertificateAuthority) error
- type CertificateService
- func (l *CertificateService) Create(ctx context.Context, certificate *certv1.Certificate) (*certv1.Certificate, error)
- func (l *CertificateService) Delete(ctx context.Context, id keys.ID) error
- func (l *CertificateService) Get(ctx context.Context, id keys.ID) (*certv1.Certificate, error)
- func (l *CertificateService) List(ctx context.Context, limit int32) ([]*certv1.Certificate, error)
- func (l *CertificateService) Patch(ctx context.Context, id keys.ID, patch *certv1.Certificate) error
- func (l *CertificateService) Update(ctx context.Context, id keys.ID, certificate *certv1.Certificate) error
- type CredentialService
- func (l *CredentialService) Create(ctx context.Context, credential *credentialv1.Credential) (*credentialv1.Credential, error)
- func (l *CredentialService) Delete(ctx context.Context, id keys.ID) error
- func (l *CredentialService) Get(ctx context.Context, id keys.ID) (*credentialv1.Credential, error)
- func (l *CredentialService) List(ctx context.Context, limit int32) ([]*credentialv1.Credential, error)
- func (l *CredentialService) Patch(ctx context.Context, id keys.ID, patch *credentialv1.Credential) error
- func (l *CredentialService) Update(ctx context.Context, id keys.ID, credential *credentialv1.Credential) error
- type EventService
- type IssueResponse
- type MetricsService
- type PolicyService
- func (l *PolicyService) Create(ctx context.Context, policy *policyv1.Policy) (*policyv1.Policy, error)
- func (l *PolicyService) Delete(ctx context.Context, id keys.ID) error
- func (l *PolicyService) Get(ctx context.Context, id keys.ID) (*policyv1.Policy, error)
- func (l *PolicyService) List(ctx context.Context, limit int32) ([]*policyv1.Policy, error)
- func (l *PolicyService) Patch(ctx context.Context, id keys.ID, patch *policyv1.Policy) error
- func (l *PolicyService) Update(ctx context.Context, id keys.ID, policy *policyv1.Policy) error
- type RouteService
- func (l *RouteService) Create(ctx context.Context, route *routev1.Route) (*routev1.Route, error)
- func (l *RouteService) Delete(ctx context.Context, id keys.ID) error
- func (l *RouteService) Get(ctx context.Context, id keys.ID) (*routev1.Route, error)
- func (l *RouteService) List(ctx context.Context, limit int32) ([]*routev1.Route, error)
- func (l *RouteService) Patch(ctx context.Context, id keys.ID, patch *routev1.Route) error
- func (l *RouteService) Update(ctx context.Context, id keys.ID, route *routev1.Route) error
- func (l *RouteService) UpdateStatus(ctx context.Context, id keys.ID, st *routev1.RouteStatus, mask ...string) error
- type TokenManager
- type TokenService
- type TokenValidator
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseCertFromPEMFile ¶
func ParseCertFromPEMFile(pemData string) (*x509.Certificate, error)
Types ¶
type AuditService ¶
type AuditService struct {
Logger logger.Logger
Exchange *events.Exchange
Manager infra.SessionManager
Store audit.Store
}
func (*AuditService) AuditLog ¶
func (n *AuditService) AuditLog(ctx context.Context, req *auditv1.AuditLogRequest, stream auditv1.AuditService_AuditLogServer) error
AuditLog streams audit entries
type BackendService ¶
type BackendService struct {
Repo *repository.Repo[*backendv1.Backend]
Exchange *events.Exchange
Logger logger.Logger
// contains filtered or unexported fields
}
func (*BackendService) Delete ¶
Delete publishes a delete request and the subscribers are responsible for deleting resources. Once they do, they will update there resource with the status Deleted
func (*BackendService) UpdateStatus ¶
func (l *BackendService) UpdateStatus(ctx context.Context, id keys.ID, st *backendv1.BackendStatus, mask ...string) error
UpdateStatus implements [routesv1.RouteServieClient]
type CertificateAuthorityService ¶
type CertificateAuthorityService struct {
Repo *repository.Repo[*cav1.CertificateAuthority]
Exchange *events.Exchange
Logger logger.Logger
// contains filtered or unexported fields
}
func (*CertificateAuthorityService) Create ¶
func (l *CertificateAuthorityService) Create(ctx context.Context, ca *cav1.CertificateAuthority) (*cav1.CertificateAuthority, error)
func (*CertificateAuthorityService) Get ¶
func (l *CertificateAuthorityService) Get(ctx context.Context, id keys.ID) (*cav1.CertificateAuthority, error)
func (*CertificateAuthorityService) List ¶
func (l *CertificateAuthorityService) List(ctx context.Context, limit int32) ([]*cav1.CertificateAuthority, error)
func (*CertificateAuthorityService) Patch ¶
func (l *CertificateAuthorityService) Patch(ctx context.Context, id keys.ID, patch *cav1.CertificateAuthority) error
func (*CertificateAuthorityService) Update ¶
func (l *CertificateAuthorityService) Update(ctx context.Context, id keys.ID, ca *cav1.CertificateAuthority) error
type CertificateService ¶
type CertificateService struct {
Repo *repository.Repo[*certv1.Certificate]
Exchange *events.Exchange
Logger logger.Logger
// contains filtered or unexported fields
}
func (*CertificateService) Create ¶
func (l *CertificateService) Create(ctx context.Context, certificate *certv1.Certificate) (*certv1.Certificate, error)
func (*CertificateService) Get ¶
func (l *CertificateService) Get(ctx context.Context, id keys.ID) (*certv1.Certificate, error)
func (*CertificateService) List ¶
func (l *CertificateService) List(ctx context.Context, limit int32) ([]*certv1.Certificate, error)
func (*CertificateService) Patch ¶
func (l *CertificateService) Patch(ctx context.Context, id keys.ID, patch *certv1.Certificate) error
func (*CertificateService) Update ¶
func (l *CertificateService) Update(ctx context.Context, id keys.ID, certificate *certv1.Certificate) error
type CredentialService ¶
type CredentialService struct {
Repo *repository.Repo[*credentialv1.Credential]
Exchange *events.Exchange
Logger logger.Logger
// contains filtered or unexported fields
}
func (*CredentialService) Create ¶
func (l *CredentialService) Create(ctx context.Context, credential *credentialv1.Credential) (*credentialv1.Credential, error)
func (*CredentialService) Delete ¶
Delete publishes a delete request and the subscribers are responsible for deleting resources. Once they do, they will update there resource with the status Deleted
func (*CredentialService) Get ¶
func (l *CredentialService) Get(ctx context.Context, id keys.ID) (*credentialv1.Credential, error)
func (*CredentialService) List ¶
func (l *CredentialService) List(ctx context.Context, limit int32) ([]*credentialv1.Credential, error)
func (*CredentialService) Patch ¶
func (l *CredentialService) Patch(ctx context.Context, id keys.ID, patch *credentialv1.Credential) error
func (*CredentialService) Update ¶
func (l *CredentialService) Update(ctx context.Context, id keys.ID, credential *credentialv1.Credential) error
type EventService ¶
type EventService struct {
Logger logger.Logger
Exchange *events.Exchange
Manager infra.SessionManager
}
func (*EventService) Publish ¶
func (n *EventService) Publish(ctx context.Context, ev *eventv1.Envelope) (*eventv1.Envelope, error)
Publish implements events.EventServiceClient.
func (*EventService) Subscribe ¶
func (n *EventService) Subscribe(ctx context.Context, in infra.NodeConnectInput) (infra.Session, error)
Subscribe implements events.EventServiceClient.
type IssueResponse ¶
type MetricsService ¶
type MetricsService struct {
Logger logger.Logger
Exchange *events.Exchange
Metrics *proxy.ProxyMetrics
}
func (*MetricsService) MetricsLog ¶
func (n *MetricsService) MetricsLog(ctx context.Context) (*proxy.ProxyMetrics, error)
MetricsLog streams metrics entries
type PolicyService ¶
type PolicyService struct {
Repo *repository.Repo[*policyv1.Policy]
Exchange *events.Exchange
Logger logger.Logger
// contains filtered or unexported fields
}
type RouteService ¶
type RouteService struct {
Repo *repository.Repo[*routev1.Route]
Exchange *events.Exchange
Logger logger.Logger
// contains filtered or unexported fields
}
func (*RouteService) Delete ¶
Delete publishes a delete request and the subscribers are responsible for deleting resources. Once they do, they will update there resource with the status Deleted
func (*RouteService) UpdateStatus ¶
func (l *RouteService) UpdateStatus(ctx context.Context, id keys.ID, st *routev1.RouteStatus, mask ...string) error
UpdateStatus implements [routesv1.RouteServieClient]
type TokenManager ¶
type TokenService ¶
type TokenService struct {
// Repo *repository.Repo[*tokenv1.Token]
Exchange *events.Exchange
Logger logger.Logger
Key *ecdsa.PrivateKey
DefaultTTL time.Duration
MaxTTL time.Duration
DefaultAud []string
Issuer string
SigningKeyID string
}
func (*TokenService) IssueToken ¶
func (s *TokenService) IssueToken(ctx context.Context, req *tokenv1.TokenConfig) (*tokenv1.IssueResponse, error)